import 'option.dart';
import 'terminal.dart';

final Terminal _terminal = const Terminal();

class Prompter {
  bool askBinary(String prompt) {
    _terminal.clearScreen();
    _terminal.printPrompt('$prompt (y/n)');
    _terminal.printCaret();
    final input = _ask(prompt, []).toLowerCase();
    if (input.length > 0) {
      return input.contains('y');
    } else {
      return askBinary(prompt);
    }
  }

  String askMultiple(String prompt, List<Option> options) {
    final input = _ask(prompt, options);
    if (input.length > 0) {
      if (RegExp('^[0-9]\$').hasMatch(input)) {
        final index = int.parse(input) - 1;
        if (index >= 0 && index < options.length) {
          return options[index].value;
        }
      }
    }
    return askMultiple(prompt, options);
  }

  String _ask(String prompt, List<Option> options) {
    _terminal.clearScreen();
    _terminal.printPrompt(prompt);
    if (options.length > 0) {
      _terminal.printOptions(options);
    } else {
      _terminal.printCaret();
    }
    return _terminal.collectInput().trim();
  }
}
